==> open-xchange-guard_2.6.0.orig.tar.bz2: open-xchange-guard-2.6.0/com.openexchange.guard.user/src/com/openexchange/guard/user/GuardCapabilities.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.guard.user;

public class GuardCapabilities {

    public enum Permissions {
        NONE, GUARD, MAIL, FILE, GUARD_MAIL_FILE
    };

    private Permissions perm = Permissions.NONE;
    private boolean privatepass = true;
    private boolean noDeleteRecovery = false;
    private boolean noDeletePrivate = false;
    private boolean norecovery = false;

    /**
     * Initialises a new {@link GuardCapabilities}.
     */
    public GuardCapabilities() {
        super();
    }

    /**
     * Gets the perm
     *
     * @return The perm
     */
    public Permissions getPerm() {
        return perm;
    }

    /**
     * Sets the perm
     *
     * @param perm The perm to set
     */
    public void setPerm(Permissions perm) {
        this.perm = perm;
    }

    /**
     * Gets the privatepass
     *
     * @return The privatepass
     */
    public boolean isPrivatepass() {
        return privatepass;
    }

    /**
     * Sets the privatepass
     *
     * @param privatepass The privatepass to set
     */
    public void setPrivatepass(boolean privatepass) {
        this.privatepass = privatepass;
    }

    /**
     * Gets the noDeleteRecovery
     *
     * @return The noDeleteRecovery
     */
    public boolean isNoDeleteRecovery() {
        return noDeleteRecovery;
    }

    /**
     * Sets the noDeleteRecovery
     *
     * @param noDeleteRecovery The noDeleteRecovery to set
     */
    public void setNoDeleteRecovery(boolean noDeleteRecovery) {
        this.noDeleteRecovery = noDeleteRecovery;
    }

    /**
     * Gets the noDeletePrivate
     *
     * @return The noDeletePrivate
     */
    public boolean isNoDeletePrivate() {
        return noDeletePrivate;
    }

    /**
     * Sets the noDeletePrivate
     *
     * @param noDeletePrivate The noDeletePrivate to set
     */
    public void setNoDeletePrivate(boolean noDeletePrivate) {
        this.noDeletePrivate = noDeletePrivate;
    }

    /**
     * Gets the norecovery
     *
     * @return The norecovery
     */
    public boolean isNorecovery() {
        return norecovery;
    }

    /**
     * Sets the norecovery
     *
     * @param norecovery The norecovery to set
     */
    public void setNorecovery(boolean norecovery) {
        this.norecovery = norecovery;
    }

    public boolean hasPermission(GuardCapabilities.Permissions permission) {
        return this.perm == permission ||
               this.perm == Permissions.GUARD_MAIL_FILE /*highest available*/;
    }

    public boolean hasMinimumPermission() {
        return this.perm == GuardCapabilities.Permissions.GUARD ||
               this.perm == GuardCapabilities.Permissions.FILE ||
               this.perm == GuardCapabilities.Permissions.GUARD_MAIL_FILE;
    }

}

==> open-xchange-guard_2.10.3.orig.tar.bz2: open-xchange-guard-2.10.3/com.openexchange.guard.user/src/com/openexchange/guard/user/GuardCapabilities.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.guard.user;

public class GuardCapabilities {

    public enum Permissions {
        NONE, GUARD, MAIL, FILE, GUARD_MAIL_FILE
    };

    private Permissions perm = Permissions.NONE;
    private boolean privatepass = true;
    private boolean noDeleteRecovery = false;
    private boolean noDeletePrivate = false;
    private boolean norecovery = false;

    /**
     * Initialises a new {@link GuardCapabilities}.
     */
    public GuardCapabilities() {
        super();
    }

    /**
     * Gets the perm
     *
     * @return The perm
     */
    public Permissions getPerm() {
        return perm;
    }

    /**
     * Sets the perm
     *
     * @param perm The perm to set
     */
    public void setPerm(Permissions perm) {
        this.perm = perm;
    }

    /**
     * Gets the privatepass
     *
     * @return The privatepass
     */
    public boolean isPrivatepass() {
        return privatepass;
    }

    /**
     * Sets the privatepass
     *
     * @param privatepass The privatepass to set
     */
    public void setPrivatepass(boolean privatepass) {
        this.privatepass = privatepass;
    }

    /**
     * Gets the noDeleteRecovery
     *
     * @return The noDeleteRecovery
     */
    public boolean isNoDeleteRecovery() {
        return noDeleteRecovery;
    }

    /**
     * Sets the noDeleteRecovery
     *
     * @param noDeleteRecovery The noDeleteRecovery to set
     */
    public void setNoDeleteRecovery(boolean noDeleteRecovery) {
        this.noDeleteRecovery = noDeleteRecovery;
    }

    /**
     * Gets the noDeletePrivate
     *
     * @return The noDeletePrivate
     */
    public boolean isNoDeletePrivate() {
        return noDeletePrivate;
    }

    /**
     * Sets the noDeletePrivate
     *
     * @param noDeletePrivate The noDeletePrivate to set
     */
    public void setNoDeletePrivate(boolean noDeletePrivate) {
        this.noDeletePrivate = noDeletePrivate;
    }

    /**
     * Gets the norecovery
     *
     * @return The norecovery
     */
    public boolean isNorecovery() {
        return norecovery;
    }

    /**
     * Sets the norecovery
     *
     * @param norecovery The norecovery to set
     */
    public void setNorecovery(boolean norecovery) {
        this.norecovery = norecovery;
    }

    public boolean hasPermission(GuardCapabilities.Permissions permission) {
        return this.perm == permission ||
               this.perm == Permissions.GUARD_MAIL_FILE /*highest available*/;
    }

    public boolean hasMinimumPermission() {
        return this.perm == GuardCapabilities.Permissions.GUARD ||
               this.perm == GuardCapabilities.Permissions.FILE ||
               this.perm == GuardCapabilities.Permissions.GUARD_MAIL_FILE ||
               this.perm == GuardCapabilities.Permissions.MAIL;
    }

}
